@@ -69,39 +69,67 @@ static SensorValueRange sensor_value_range(gdouble sensor_value,
         return SENSOR_VALUE_RANGE(((gint)range + ((range - ((gint)range)) >= 0.5)));
 }
 
-static gboolean active_sensor_execute_alarm(ActiveSensor *active_sensor) {
-        sensors_applet_notify(active_sensor);
-        g_debug("EXECUTING ALARM: %s", active_sensor->alarm_command);
-	gnome_execute_shell(NULL, active_sensor->alarm_command);
 
-        return TRUE;
+static gboolean active_sensor_execute_alarm(ActiveSensor *active_sensor,
+                                            NotifType notif_type) {
+        int pid;
+
+        sensors_applet_notify(active_sensor, notif_type);
+        g_debug("EXECUTING %s ALARM: %s", 
+                (notif_type == LOW_ALARM ? 
+                 "LOW" : "HIGH"),
+                active_sensor->alarm_command[notif_type]);
+	pid = gnome_execute_shell(NULL, 
+                                  active_sensor->alarm_command[notif_type]);
+        g_debug("Command executed in shell with pid %d", pid);
+
+        return (pid != -1);
+}
+
+static gboolean active_sensor_execute_low_alarm(ActiveSensor *active_sensor) {
+        return active_sensor_execute_alarm(active_sensor, LOW_ALARM);
+}
+
+static gboolean active_sensor_execute_high_alarm(ActiveSensor *active_sensor) {
+        return active_sensor_execute_alarm(active_sensor, HIGH_ALARM);
 }
 
 /* needs to be able to be called by the config dialog when the alarm
  * command changes */
-void active_sensor_alarm_off(ActiveSensor *active_sensor) {
+void active_sensor_alarm_off(ActiveSensor *active_sensor,
+                             NotifType notif_type) {
 	g_assert(active_sensor);
 
-	if (active_sensor->alarm_timeout_id != -1) {
-		g_debug("Disabling alarm.");
-			/* alarm is on, cycle through list of alarm_commands
-			 * and free this one */
-		
-		if (!g_source_remove(active_sensor->alarm_timeout_id)) {
+	if (active_sensor->alarm_timeout_id[notif_type] != -1) {
+		g_debug("Disabling %s alarm.", 
+                        (notif_type == LOW_ALARM ? "LOW" : "HIGH"));
+		if (!g_source_remove(active_sensor->alarm_timeout_id[notif_type])) {
 			g_debug("Error removing alarm source");
 		}
-		g_free(active_sensor->alarm_command);
-		active_sensor->alarm_timeout_id = -1;
+		g_free(active_sensor->alarm_command[notif_type]);
+		active_sensor->alarm_timeout_id[notif_type] = -1;
 
 	}
-        sensors_applet_notify_end(active_sensor);
+        sensors_applet_notify_end(active_sensor, notif_type);
 }
 
-static void active_sensor_alarm_on(ActiveSensor *active_sensor) {
+static void active_sensor_all_alarms_off(ActiveSensor *active_sensor) {
+        /* turn off any alarms */
+        int i;
+        for (i = 0; i < NUM_ALARMS; i++) {
+                if (active_sensor->alarm_timeout_id[i] >= 0) {
+                        g_debug("-- turning off notif with type %d ---", i);
+                        active_sensor_alarm_off(active_sensor, i);
+                }
+        }
+}
+
+static void active_sensor_alarm_on(ActiveSensor *active_sensor,
+                                   NotifType notif_type) {
 	GtkTreeModel *model;
 	GtkTreePath *tree_path;
 	GtkTreeIter iter;
-
+        
 	g_assert(active_sensor);
 
 	model = gtk_tree_row_reference_get_model(active_sensor->sensor_row);
@@ -109,33 +137,44 @@ static void active_sensor_alarm_on(ActiveSensor *active_sensor) {
 
 	if (gtk_tree_model_get_iter(model, &iter, tree_path)) {
 
-		if (active_sensor->alarm_timeout_id == -1) {
-                        g_debug("Activating alarm to repeat every %d seconds", active_sensor->alarm_timeout);
+		if (active_sensor->alarm_timeout_id[notif_type] == -1) {
 			/* alarm is not currently on */			
 			gtk_tree_model_get(model,
 					   &iter,
-					   ALARM_COMMAND_COLUMN, &(active_sensor->alarm_command),
+					   (notif_type == LOW_ALARM ? 
+                                            LOW_ALARM_COMMAND_COLUMN :
+                                            HIGH_ALARM_COMMAND_COLUMN), 
+                                           &(active_sensor->alarm_command[notif_type]),
 					   ALARM_TIMEOUT_COLUMN, &(active_sensor->alarm_timeout),
 					   -1);
+                        g_debug("Activating alarm to repeat every %d seconds", active_sensor->alarm_timeout);
                         
 			/* execute alarm once, then add to time to
 			   keep repeating it */
-			active_sensor_execute_alarm(active_sensor);
-
-			if (active_sensor->alarm_timeout <= 0) {
-				active_sensor->alarm_timeout_id = g_timeout_add(G_MAXINT,
-										(GSourceFunc)active_sensor_execute_alarm,
-										active_sensor);
-			} else {
-				active_sensor->alarm_timeout_id = g_timeout_add(active_sensor->alarm_timeout * 1000,
-										(GSourceFunc)active_sensor_execute_alarm,
-										active_sensor);
-				
-			}
-		}
+			active_sensor_execute_alarm(active_sensor, notif_type);
+                        int timeout = (active_sensor->alarm_timeout <= 0 ? 
+                                       G_MAXINT : 
+                                       active_sensor->alarm_timeout * 1000);
+                        switch (notif_type) {
+                        case LOW_ALARM:
+                                active_sensor->alarm_timeout_id[notif_type] = g_timeout_add(timeout,
+                                                                                            (GSourceFunc)active_sensor_execute_low_alarm,
+                                                                                            active_sensor);
+                                break;
+                        case HIGH_ALARM:
+                                active_sensor->alarm_timeout_id[notif_type] = g_timeout_add(timeout,
+                                                                                            (GSourceFunc)active_sensor_execute_high_alarm,
+                                                                                            active_sensor);
+                                break;
+                        default:
+                                g_debug("Unkown notif type: %d", notif_type);
+                        }
+                        
+                        
+                }
 	}
 	gtk_tree_path_free(tree_path);
-
+        
 }
 
 /**
@@ -324,10 +363,7 @@ void active_sensor_destroy(ActiveSensor *active_sensor) {
         g_debug("-- destroying active sensor values...");
         g_free(active_sensor->sensor_values);
 
-        if (active_sensor->alarm_timeout_id >= 0) {
-                g_debug("-- turning off alarm---");
-                active_sensor_alarm_off(active_sensor);
-        }
+        active_sensor_all_alarms_off(active_sensor);
 
         g_free(active_sensor);
 }
@@ -405,7 +441,11 @@ ActiveSensor *active_sensor_new(SensorsApplet *sensors_applet,
         active_sensor->sensors_applet = sensors_applet;
 
 	active_sensor->sensor_row = sensor_row;
-	active_sensor->alarm_timeout_id = -1;
+
+        int i;
+        for (i = 0; i < NUM_NOTIFS; i++) {
+                active_sensor->alarm_timeout_id[i] = -1;
+        }
 
         active_sensor->label = gtk_label_new("");
         active_sensor->label_event_box = gtk_event_box_new();
@@ -727,14 +767,22 @@ void active_sensor_update(ActiveSensor *active_sensor,
                                                 
                                                 g_free(old_value_text);
                                         }
-                                        active_sensor_alarm_on(active_sensor);
+                                        /* could have both coditions at once */
+                                        if (sensor_value >= sensor_high_value) {
+                                                active_sensor_alarm_on(active_sensor, HIGH_ALARM);
+                                        }
+
+                                        if (sensor_value <= sensor_low_value) {
+                                                active_sensor_alarm_on(active_sensor, LOW_ALARM);
+                                        }
+                                        
                                 } else {
-                                        /* make sure alarm is off */
-                                        active_sensor_alarm_off(active_sensor);
+                                        /* make sure alarms are off */
+                                        active_sensor_all_alarms_off(active_sensor);
                                 }				
                         } else { /* else for if alarm enabled */
-                                /* make sure alarm is off */
-                                active_sensor_alarm_off(active_sensor);
+                                /* make sure all alarms are off */
+                                active_sensor_all_alarms_off(active_sensor);
                         }
 			
                         /* do value label */
