@@ -48,14 +48,14 @@ struct _ActiveSensor {
 	GtkTreeRowReference *sensor_row;
 
 #ifdef HAVE_LIBNOTIFY
-        NotifyNotification *notification;
+        NotifyNotification *notification[NUM_ALARMS];
 #endif
 
         gboolean updated;
 
 	/* alarm related stuff */
-	gint alarm_timeout_id;
-	gchar *alarm_command;
+	gint alarm_timeout_id[NUM_ALARMS];
+	gchar *alarm_command[NUM_ALARMS];
         gint alarm_timeout;
 
 	/* buffer of sensor values */
@@ -65,8 +65,7 @@ struct _ActiveSensor {
         gint num_samples;
         
 	gdouble sensor_low_value;
-	gdouble sensor_high_value;
-	
+	gdouble sensor_high_value;	
 };
 
 ActiveSensor *active_sensor_new(SensorsApplet *sensors_applet,
@@ -77,5 +76,5 @@ void active_sensor_update(ActiveSensor *sensor, SensorsApplet *sensors_applet);
 void active_sensor_icon_changed(ActiveSensor *sensor, SensorsApplet *sensors_applet);
 void active_sensor_update_graph_dimensions(ActiveSensor *as,
                                            gint dimensions[2]);
-void active_sensor_alarm_off(ActiveSensor *active_sensor);
+void active_sensor_alarm_off(ActiveSensor *active_sensor, NotifType notif_type);
 #endif /* ACTIVE_SENSOR_H */
