@@ -132,7 +132,7 @@ static GQuark i2c_proc_sensors_interface_device_file_error_quark(void) {
 	gchar *string;
 
 	if (quark == 0) {
-		string = g_strdup_printf("%s-device-file-error", sensor_interface[I2C_PROC]);
+		string = g_strdup_printf("%s-device-file-error", SENSORS_INTERFACE_STRING(I2C_PROC));
 		quark = g_quark_from_string(string);
 		g_free(string);
 	}
