@@ -80,7 +80,7 @@ static GQuark i8k_sensors_interface_device_file_error_quark(void) {
 	gchar *string;
 
 	if (quark == 0) {
-		string = g_strdup_printf("%s-device-file-error", sensor_interface[I8K]);
+		string = g_strdup_printf("%s-device-file-error", SENSORS_INTERFACE_STRING(I8K));
 		quark = g_quark_from_string(string);
 		g_free(string);
 	}
