@@ -98,7 +98,7 @@ static GQuark libsensors_sensors_interface_error_quark(void) {
 	gchar *string;
 
 	if (quark == 0) {
-		string = g_strdup_printf("%s-error", sensor_interface[LIBSENSORS]);
+		string = g_strdup_printf("%s-error", SENSORS_INTERFACE_STRING(LIBSENSORS));
 		quark = g_quark_from_string(string);
 		g_free(string);
 	}
