@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005 Alex Murray <pragmatine@gmail.com>
+ * Copyright (C) 2005-2006 Alex Murray <pragmatine@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,11 +24,12 @@
 #include <string.h>
 #include "sensors-applet.h"
 
-static gboolean sensors_applet_fill(PanelApplet *applet, const gchar *iid, gpointer data) {
+static gboolean sensors_applet_fill(PanelApplet *applet, 
+                                    const gchar *iid, 
+                                    gpointer data) {
 	SensorsApplet *sensors_applet;
 	gboolean retval = FALSE;
-
-	if (strcmp(iid, "OAFIID:SensorsApplet") == 0) {
+        if (strcmp(iid, "OAFIID:SensorsApplet") == 0) {
 		sensors_applet = g_new0(SensorsApplet, 1);
 		sensors_applet->applet = applet;
 		sensors_applet_init(sensors_applet);
