@@ -122,7 +122,7 @@ static GQuark pmu_sys_sensors_interface_device_file_error_quark(void) {
 	gchar *string;
 
 	if (quark == 0) {
-		string = g_strdup_printf("%s-device-file-error", sensor_interface[PMU_SYS]);
+		string = g_strdup_printf("%s-device-file-error", SENSORS_INTERFACE_STRING(PMU_SYS));
 		quark = g_quark_from_string(string);
 		g_free(string);
 	}
