@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005 Alex Murray <pragmatine@gmail.com>
+ * Copyright (C) 2005-2006 Alex Murray <pragmatine@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,6 +23,6 @@
 
 /* function definition */
 
-void sensor_config_dialog_create(GtkButton *button, SensorsApplet *sensors_applet);
+void sensor_config_dialog_create(SensorsApplet *sensors_applet);
 
 #endif /* SENSOR_CONFIG_DIALOG_H */
