@@ -29,6 +29,8 @@
 /* always list current version */
 static const gchar * const compatible_versions[] = {
         PACKAGE_VERSION,
+        "1.7.9",
+        "1.7.8",
         "1.7.7",
         "1.7.6",
         "1.7.5",
@@ -125,8 +127,43 @@ void sensors_applet_gconf_setup(SensorsApplet *sensors_applet) {
                                            GRAPH_SIZE,
                                            (num_samples + GRAPH_FRAME_EXTRA_WIDTH),
                                            NULL);
+                /* reset num_samples to zero */
+                panel_applet_gconf_set_int(sensors_applet->applet,
+                                           "num_samples",
+                                           0,
+                                           NULL);
+                
         }                                      
-        
+
+        /* convert old alarm_commands to high and low if exist */
+        GSList *alarm_commands;
+        if ((alarm_commands = panel_applet_gconf_get_list(sensors_applet->applet,
+                                                          "alarm_commands",
+                                                          GCONF_VALUE_STRING,
+                                                          NULL))) {
+                
+                g_debug("Converting old alarm commands to new high and low commands");
+                
+                panel_applet_gconf_set_list(sensors_applet->applet,
+                                            LOW_ALARM_COMMANDS,
+                                            GCONF_VALUE_STRING,
+                                            alarm_commands,
+                                            NULL);
+                panel_applet_gconf_set_list(sensors_applet->applet,
+                                            HIGH_ALARM_COMMANDS,
+                                            GCONF_VALUE_STRING,
+                                            alarm_commands,
+                                            NULL);
+                /* reset old list to null */
+                panel_applet_gconf_set_list(sensors_applet->applet,
+                                            "alarm_commands",
+                                            GCONF_VALUE_STRING,
+                                            NULL,
+                                            NULL);
+                g_slist_foreach(alarm_commands, (GFunc)g_free, NULL);
+                g_slist_free(alarm_commands);
+                
+        }
 
         setup = panel_applet_gconf_get_bool(sensors_applet->applet, 
                                             IS_SETUP, &error);
@@ -191,7 +228,8 @@ enum {
         LOW_VALUES_INDEX, 
         HIGH_VALUES_INDEX, 
         ALARM_ENABLES_INDEX, 
-        ALARM_COMMANDS_INDEX, 
+        LOW_ALARM_COMMANDS_INDEX, 
+        HIGH_ALARM_COMMANDS_INDEX,
         ALARM_TIMEOUTS_INDEX, 
         MULTIPLIERS_INDEX,
         OFFSETS_INDEX,
@@ -210,7 +248,8 @@ const gchar * const keys[NUM_KEYS] = {
         LOW_VALUES, 
         HIGH_VALUES, 
         ALARM_ENABLES, 
-        ALARM_COMMANDS, 
+        LOW_ALARM_COMMANDS,
+        HIGH_ALARM_COMMANDS,
         ALARM_TIMEOUTS, 
         MULTIPLIERS,
         OFFSETS,
@@ -229,7 +268,8 @@ const GConfValueType key_types[NUM_KEYS] = {
         GCONF_VALUE_INT, /* LOW_VALUES, */
         GCONF_VALUE_INT, /* HIGH_VALUES, */
         GCONF_VALUE_BOOL, /* ALARM_ENABLES, */
-        GCONF_VALUE_STRING, /* ALARM_COMMANDS, */
+        GCONF_VALUE_STRING, /* LOW_ALARM_COMMANDS, */
+        GCONF_VALUE_STRING, /* HIGH_ALARM_COMMANDS, */
         GCONF_VALUE_INT, /* ALARM_TIMEOUTS, */
         GCONF_VALUE_INT, /* MULTIPLIERS, */
         GCONF_VALUE_INT, /* OFFSETS, */
@@ -320,7 +360,8 @@ gboolean sensors_applet_gconf_setup_sensors(SensorsApplet *sensors_applet) {
 						       (gdouble)(GPOINTER_TO_INT(current[LOW_VALUES_INDEX]->data) / 1000.0),
 						       (gdouble)(GPOINTER_TO_INT(current[HIGH_VALUES_INDEX]->data) / 1000.0),
 						       GPOINTER_TO_INT(current[ALARM_ENABLES_INDEX]->data),
-						       (gchar *)(current[ALARM_COMMANDS_INDEX]->data),
+						       (gchar *)(current[LOW_ALARM_COMMANDS_INDEX]->data),
+						       (gchar *)(current[HIGH_ALARM_COMMANDS_INDEX]->data),
 						       GPOINTER_TO_INT(current[ALARM_TIMEOUTS_INDEX]->data),
 						       (gdouble)(GPOINTER_TO_INT(current[MULTIPLIERS_INDEX]->data) / 1000.0),
 						       (gdouble)(GPOINTER_TO_INT(current[OFFSETS_INDEX]->data) / 1000.0),
@@ -350,7 +391,8 @@ gboolean sensors_applet_gconf_save_sensors(SensorsApplet *sensors_applet) {
         GSList *lists[NUM_KEYS] = {NULL};
         int i;
         gchar *current_path, *current_id, *current_label, 
-                *current_alarm_command, *current_graph_color;
+                *current_low_alarm_command, *current_high_alarm_command, 
+                *current_graph_color;
         gboolean current_enable, current_alarm_enable;
 	gdouble current_low_value, current_high_value, current_multiplier, 
                 current_offset;
@@ -386,7 +428,8 @@ gboolean sensors_applet_gconf_save_sensors(SensorsApplet *sensors_applet) {
 					   LOW_VALUE_COLUMN, &current_low_value,
 					   HIGH_VALUE_COLUMN, &current_high_value,
 					   ALARM_ENABLE_COLUMN, &current_alarm_enable,
-					   ALARM_COMMAND_COLUMN, &current_alarm_command,
+					   LOW_ALARM_COMMAND_COLUMN, &current_low_alarm_command,
+					   HIGH_ALARM_COMMAND_COLUMN, &current_high_alarm_command,
 					   ALARM_TIMEOUT_COLUMN, &current_alarm_timeout,
 					   MULTIPLIER_COLUMN, &current_multiplier,
 					   OFFSET_COLUMN, &current_offset,
@@ -404,7 +447,8 @@ gboolean sensors_applet_gconf_save_sensors(SensorsApplet *sensors_applet) {
 			lists[LOW_VALUES_INDEX] = g_slist_prepend(lists[LOW_VALUES_INDEX], GINT_TO_POINTER((gint)(current_low_value * 1000)));
 			lists[HIGH_VALUES_INDEX] = g_slist_prepend(lists[HIGH_VALUES_INDEX], GINT_TO_POINTER((gint)(current_high_value * 1000)));
 			lists[ALARM_ENABLES_INDEX] = g_slist_prepend(lists[ALARM_ENABLES_INDEX], GINT_TO_POINTER(current_alarm_enable));
-			lists[ALARM_COMMANDS_INDEX] = g_slist_prepend(lists[ALARM_COMMANDS_INDEX], current_alarm_command);
+			lists[LOW_ALARM_COMMANDS_INDEX] = g_slist_prepend(lists[LOW_ALARM_COMMANDS_INDEX], current_low_alarm_command);
+			lists[HIGH_ALARM_COMMANDS_INDEX] = g_slist_prepend(lists[HIGH_ALARM_COMMANDS_INDEX], current_high_alarm_command);
 			lists[ALARM_TIMEOUTS_INDEX] = g_slist_prepend(lists[ALARM_TIMEOUTS_INDEX], GINT_TO_POINTER(current_alarm_timeout));
 			lists[SENSOR_TYPES_INDEX] = g_slist_prepend(lists[SENSOR_TYPES_INDEX], GUINT_TO_POINTER(current_sensor_type));
 			lists[MULTIPLIERS_INDEX] = g_slist_prepend(lists[MULTIPLIERS_INDEX], GINT_TO_POINTER((gint)(current_multiplier * 1000)));
