@@ -265,7 +265,7 @@ static const BonoboUIVerb sensors_applet_menu_verbs[] = {
 };
 
 
-void sensors_applet_notify(ActiveSensor *active_sensor) {
+void sensors_applet_notify(ActiveSensor *active_sensor, NotifType notif_type) {
 #ifdef HAVE_LIBNOTIFY
  
         SensorsApplet *sensors_applet;
@@ -309,11 +309,13 @@ void sensors_applet_notify(ActiveSensor *active_sensor) {
         }
         g_list_free(table_children);
         
-        if (active_sensor->sensor_values[0] <= active_sensor->sensor_low_value) {
+        if (active_sensor->sensor_values[0] <= active_sensor->sensor_low_value &&
+                notif_type == LOW_ALARM) {
                 relation = _("is very low");
                 limit_type = _("lower limit");
                 limit_value = active_sensor->sensor_low_value;
-        } else if (active_sensor->sensor_values[0] >= active_sensor->sensor_low_value) {
+        } else if (active_sensor->sensor_values[0] >= active_sensor->sensor_high_value &&
+                notif_type == HIGH_ALARM) {
                 /* assume high alarm condition */
                 relation = _("is very high");
                 limit_type = _("upper limit");
@@ -383,6 +385,7 @@ void sensors_applet_notify(ActiveSensor *active_sensor) {
                                   relation, limit_type, limit_value, units);  
 
         active_sensor_libnotify_notify(active_sensor,
+                                       notif_type,
                                        summary,
                                        message,
                                        GTK_STOCK_DIALOG_WARNING,
@@ -394,16 +397,18 @@ void sensors_applet_notify(ActiveSensor *active_sensor) {
 #endif
 }
 
-void sensors_applet_notify_end(ActiveSensor *active_sensor) {
+void sensors_applet_notify_end(ActiveSensor *active_sensor, 
+                               NotifType notif_type) {
 #ifdef HAVE_LIBNOTIFY
-        active_sensor_libnotify_notify_end(active_sensor);
+        active_sensor_libnotify_notify_end(active_sensor, notif_type);
 #endif
 }
 
 #ifdef HAVE_LIBNOTIFY
 static void sensors_applet_notify_end_all_gfunc(ActiveSensor *active_sensor,
                                                 gpointer data) {
-        active_sensor_libnotify_notify_end(active_sensor);
+        active_sensor_libnotify_notify_end(active_sensor, LOW_ALARM);
+        active_sensor_libnotify_notify_end(active_sensor, HIGH_ALARM);
 }
 #endif
 
@@ -840,8 +845,8 @@ static void sensors_applet_pack_display(SensorsApplet *sensors_applet) {
 void sensors_applet_register_sensors_interface(SensorsApplet *sensors_applet,
                                                SensorInterface interface,
 					       GetSensorValueFunction get_sensor_value_function) {
-        g_debug("registering %s sensors interface", sensor_interface[interface]);
-	sensors_applet->get_sensor_value[interface] = get_sensor_value_function;
+        g_debug("registering %s sensors interface", SENSORS_INTERFACE_STRING(interface));
+	sensors_applet->get_sensor_value[CLAMP_SENSOR_INTERFACE_INDEX(interface)] = get_sensor_value_function;
 }
 
 /* must unref when done with returned pixbuf */
@@ -860,40 +865,28 @@ GdkPixbuf *sensors_applet_load_icon(IconType icon_type) {
                                         GTK_ICON_LOOKUP_USE_BUILTIN,
                                         &error);
 	if (error) {
+                g_warning ("Could not load icon: %s", error->message);
                 g_error_free(error);
                 error = NULL;
-
-		 /* try again with default icon */
-                 icon = gtk_icon_theme_load_icon(icon_theme,
-                                                 fallback_icons[icon_type],
-                                                 DEFAULT_ICON_SIZE,
-                                                 GTK_ICON_LOOKUP_USE_BUILTIN,
-                                                 &error);
-                 if (error) {
-			 g_warning ("Could not load fallback icon: %s", error->message);
-			 g_error_free(error);
-			 error = NULL;
-
-                         /* try again with default icon */
-                         icon = gtk_icon_theme_load_icon(icon_theme,
-                                                         GTK_STOCK_MISSING_IMAGE,
-                                                         DEFAULT_ICON_SIZE,
-                                                         GTK_ICON_LOOKUP_USE_BUILTIN,
-                                                         &error);
-                         if (error) {
-                                 /* this will quit sensors-applet but
-                                  * it is a pretty major error so may
-                                  * as well */
-
-                                 g_error("Could not load GTK_STOCK_MISSING_IMAGE - major error!!!: %s", error->message);
-                                 
-                                 g_error_free(error);
-                                 error = NULL;
-                         }
+                
+                /* try again with default icon */
+                icon = gtk_icon_theme_load_icon(icon_theme,
+                                                GTK_STOCK_MISSING_IMAGE,
+                                                DEFAULT_ICON_SIZE,
+                                                GTK_ICON_LOOKUP_USE_BUILTIN,
+                                                &error);
+                if (error) {
+                        /* this will quit sensors-applet but
+                         * it is a pretty major error so may
+                         * as well */
+                        
+                        g_error("Could not load GTK_STOCK_MISSING_IMAGE - major error!!!: %s", error->message);
+                        
+                        g_error_free(error);
+                        error = NULL;
+                }
                          
-                         
-		 }
-	}
+        }
         return icon;
 }
 
@@ -907,7 +900,8 @@ gboolean sensors_applet_add_sensor_full_details(SensorsApplet *sensors_applet,
 						gdouble low_value,
 						gdouble high_value,
 						gboolean alarm_enable,
-						const gchar *alarm_command,
+						const gchar *low_alarm_command,
+						const gchar *high_alarm_command,
 						gint alarm_timeout,
 						gdouble multiplier,
 						gdouble offset,
@@ -947,7 +941,8 @@ gboolean sensors_applet_add_sensor_full_details(SensorsApplet *sensors_applet,
 							     G_TYPE_DOUBLE, /* low value */
 							     G_TYPE_DOUBLE, /* high type */
 							     G_TYPE_BOOLEAN, /* alarm enable */
-							     G_TYPE_STRING, /* alarm command */ 
+							     G_TYPE_STRING, /* low alarm command */ 
+							     G_TYPE_STRING, /* high alarm command */ 
 							     G_TYPE_UINT, /* alarm timeout */
 							     G_TYPE_DOUBLE, /* multiplier */
 							     G_TYPE_DOUBLE, /* offset */
@@ -1003,11 +998,11 @@ gboolean sensors_applet_add_sensor_full_details(SensorsApplet *sensors_applet,
 		
 		gtk_tree_store_set(sensors_applet->sensors,
 				   &interfaces_iter,
-				   ID_COLUMN, sensor_interface[interface],
+				   ID_COLUMN, SENSORS_INTERFACE_STRING(interface),
 				   INTERFACE_COLUMN, interface,
 				   VISIBLE_COLUMN, FALSE,
 				   -1);
-                g_debug("Added sensor interface %s to tree", sensor_interface[interface]);
+                g_debug("Added sensor interface %s to tree", SENSORS_INTERFACE_STRING(interface));
 	}
 
         icon = sensors_applet_load_icon(icon_type);
@@ -1034,8 +1029,9 @@ gboolean sensors_applet_add_sensor_full_details(SensorsApplet *sensors_applet,
 			   LOW_VALUE_COLUMN, low_value,
 			   HIGH_VALUE_COLUMN, high_value,
 			   ALARM_ENABLE_COLUMN, alarm_enable,
-			   ALARM_COMMAND_COLUMN, alarm_command,
 			   ALARM_TIMEOUT_COLUMN, alarm_timeout,
+			   LOW_ALARM_COMMAND_COLUMN, low_alarm_command,
+			   HIGH_ALARM_COMMAND_COLUMN, high_alarm_command,
 			   MULTIPLIER_COLUMN, multiplier,
 			   OFFSET_COLUMN, offset,
 			   ICON_TYPE_COLUMN, icon_type,
@@ -1113,6 +1109,7 @@ gboolean sensors_applet_add_sensor(SensorsApplet *sensors_applet,
 						      high_value,
 						      FALSE,
 						      "",
+                                                      "",
 						      0,
 						      1.0,
 						      0.0,
@@ -1129,15 +1126,23 @@ void sensors_applet_display_layout_changed(SensorsApplet *sensors_applet) {
 }
 
 void sensors_applet_alarm_off(SensorsApplet *sensors_applet,
-                              GtkTreePath *path) {
+                              GtkTreePath *path,
+                              NotifType notif_type) {
 	ActiveSensor *active_sensor;
 
 	if ((active_sensor = sensors_applet_find_active_sensor(sensors_applet,
                                                                path)) != NULL) {
-		active_sensor_alarm_off(active_sensor);
+		active_sensor_alarm_off(active_sensor, notif_type);
 	}
 }
 				
+void sensors_applet_all_alarms_off(SensorsApplet *sensors_applet,
+                                   GtkTreePath *path) {
+        sensors_applet_alarm_off(sensors_applet, path, LOW_ALARM);
+        sensors_applet_alarm_off(sensors_applet, path, HIGH_ALARM);
+}
+
+
 void sensors_applet_sensor_enabled(SensorsApplet *sensors_applet,
                                    GtkTreePath *path) {
 	ActiveSensor *active_sensor;
