@@ -47,24 +47,12 @@ typedef enum {
         NUM_ICONS,
 } IconType;
 
-/* use gnome standard names */
 static const gchar * const stock_icons[NUM_ICONS] = {
-        "cpu", /* could also use "gnome-fs-chardev" */
-        "gnome-dev-harddisk", /* could also use GTK_STOCK_HARDDISK */
-        "gnome-dev-battery",
-        "memory",
-        "gpu",
-        "chip",
-        "fan",
-        "case"
-};
-
-static const gchar * const fallback_icons[NUM_ICONS] = {
         "sensors-applet-cpu",
         "sensors-applet-drive-harddisk",
         "sensors-applet-battery",
         "sensors-applet-memory",
-        "sensors-applet-chip", /* no GPU Icon yet */
+        "sensors-applet-gpu",
         "sensors-applet-chip",
         "sensors-applet-fan",
         "sensors-applet-case"
@@ -117,6 +105,9 @@ static const gchar *sensor_interface[] = {
 	"nvidia",
         "sonypi",
 };
+#define CLAMP_SENSOR_INTERFACE_INDEX(n) CLAMP(n, 0, G_N_ELEMENTS(sensor_interface))
+
+#define SENSORS_INTERFACE_STRING(n) sensor_interface[CLAMP_SENSOR_INTERFACE_INDEX(n)]
 
 /* enumeration used to identify columns in the GtkTreeStore data
  * structure and to access specific gconf keys too.
@@ -132,7 +123,8 @@ enum {
        	LOW_VALUE_COLUMN,
 	HIGH_VALUE_COLUMN, 
 	ALARM_ENABLE_COLUMN,
-	ALARM_COMMAND_COLUMN,
+	LOW_ALARM_COMMAND_COLUMN,
+        HIGH_ALARM_COMMAND_COLUMN,
 	ALARM_TIMEOUT_COLUMN,
 	MULTIPLIER_COLUMN,
 	OFFSET_COLUMN,
@@ -170,6 +162,16 @@ typedef enum {
         FAHRENHEIT
 } TemperatureScale;
 
+/* two types of Notifs - low and high alarms */
+typedef enum {
+        LOW_ALARM = 0,
+        HIGH_ALARM,
+        NUM_NOTIFS
+} NotifType;
+
+/* only always two type of alarms - may have more notif types */
+#define NUM_ALARMS 2
+
 /* should always return the value in degrees celcius, revolutions per
  * minute, volts, amps, etc */
 typedef gdouble (*GetSensorValueFunction)(const gchar *path, 
@@ -221,7 +223,8 @@ gboolean sensors_applet_add_sensor_full_details(SensorsApplet *sensors_applet,
 						gdouble low_value,
 						gdouble high_value,
 						gboolean alarm_enable,
-						const gchar *alarm_command,
+						const gchar *low_alarm_command,
+						const gchar *high_alarm_command,
 						gint alarm_timeout,
 						gdouble multiplier,
 						gdouble offset,
@@ -241,6 +244,9 @@ gboolean sensors_applet_add_sensor(SensorsApplet *sensors_applet,
  * to be called by things like prefs dialog to turn off a sensor alarm
  */
 void sensors_applet_alarm_off(SensorsApplet *sensors_applet,
+                              GtkTreePath *path,
+                              NotifType notif_type);
+void sensors_applet_all_alarms_off(SensorsApplet *sensors_applet,
                               GtkTreePath *path);
 void sensors_applet_icon_changed(SensorsApplet *sensors_applet,
                                  GtkTreePath *path);
@@ -253,9 +259,9 @@ gdouble sensors_applet_convert_temperature(gdouble value,
                                            TemperatureScale old, 
                                            TemperatureScale new);
 
-void sensors_applet_notify_end(ActiveSensor *active_sensor);
+void sensors_applet_notify_end(ActiveSensor *active_sensor, NotifType notif_type);
 void sensors_applet_notify_end_all(SensorsApplet *sensors_applet);
-void sensors_applet_notify(ActiveSensor *active_sensor);
+void sensors_applet_notify(ActiveSensor *active_sensor, NotifType notif_type);
 GdkPixbuf *sensors_applet_load_icon(IconType icon_type);
 void sensors_applet_graph_size_changed(SensorsApplet *sensors_applet);
 
